/* layout */
import Layout from '@/components/layout/layout.vue'

export default [
  { path: '*', redirect: '/goods' },
  {
    path: '/dashboard',
    component: Layout,
    props: { hasBreadcrumb: false },
    children: [
      {
        path: '',
        component: () => import(/* webpackChunkName: "dashboard" */ '@/pages/dashboard/index.vue'),
        meta: { title: '概况' }
      }
    ]
  },
  // 店铺
  {
    path: '/shop',
    component: () => import(/* webpackChunkName: "shop" */ '@/pages/shop/index.vue'),
    meta: { title: '选择店铺' }
  },
  {
    path: '/shop/add',
    component: () => import(/* webpackChunkName: "shop" */ '@/pages/shop/add.vue'),
    meta: { title: '新建店铺' }
  },
  // 商品管理
  {
    path: '/goods',
    component: Layout,
    meta: { title: '商品' },
    children: [
      {
        name: 'goodsList',
        path: '',
        component: () => import(/* webpackChunkName: "goods" */ '@/pages/goods/goods/index.vue'),
        meta: { title: '商品列表' }
      },
      {
        name: 'goodsAdd',
        path: 'add',
        component: () => import(/* webpackChunkName: "goods" */ '@/pages/goods/goods/edit.vue'),
        meta: { title: '发布商品' }
      },
      {
        name: 'goodsEdit',
        path: 'edit/:id',
        component: () => import(/* webpackChunkName: "goods" */ '@/pages/goods/goods/edit.vue'),
        props: { isEdit: true },
        meta: { title: '编辑商品' }
      },
      {
        path: 'group',
        component: () => import(/* webpackChunkName: "goods-group" */ '@/pages/goods/group/index.vue'),
        meta: { title: '商品分组' }
      }
    ]
  },
  // 订单管理
  {
    path: '/order',
    component: Layout,
    meta: { title: '订单' },
    children: [
      {
        name: 'orderList',
        path: '',
        component: () => import(/* webpackChunkName: "order" */ '@/pages/order/index.vue'),
        meta: { title: '订单列表' }
      },
      {
        name: 'orderDetail',
        path: 'detail/:id',
        component: () => import(/* webpackChunkName: "order" */ '@/pages/order/detail.vue'),
        meta: { title: '订单详情' }
      },
      {
        name: 'orderAdd',
        path: 'add',
        component: () => import(/* webpackChunkName: "order" */ '@/pages/order/add.vue'),
        meta: { title: '新增订单' }
      }
    ]
  },
  // 设置
  {
    path: '/setting',
    component: Layout,
    meta: { title: '设置' },
    children: [
      { path: '', redirect: 'info' },
      {
        path: 'info',
        component: () => import(/* webpackChunkName: "setting" */ '@/pages/setting/info.vue'),
        meta: { title: '店铺信息' }
      },
      {
        path: 'general',
        component: () => import(/* webpackChunkName: "setting" */ '@/pages/setting/general.vue'),
        meta: { title: '通用设置' }
      },
      {
        path: 'contact',
        component: () => import(/* webpackChunkName: "setting" */ '@/pages/setting/contact.vue'),
        meta: { title: '联系我们' }
      },
      {
        path: 'goods',
        component: () => import(/* webpackChunkName: "setting" */ '@/pages/setting/goods.vue'),
        meta: { title: '商品设置' }
      }
    ]
  },
  {
    path: '/preview',
    component: () => import(/* webpackChunkName: "preview" */ '@/pages/preview.vue')
  }
]
